utils::globalVariables(c(
  "id", "value", "lags",
  "value_forecast", "value_lower_joint", "value_upper_joint", "forecast",
  "p",
  ".",
  "Model", "name", "score", "average", "coef_hat", "Loss",
  "model",
  "sd",
  "impulse", "period", "response",
  "term", "statistic", "estimate",
  "conf.low", "conf.high", "coef",
  "x", "y", "ord",
  "iter_id", "h_name", "varying_name", "row_unique"
))